%define	italcgrp veyon

Name:		veyon
# version used by GlobalConfig.xml
Version:	4.9.4
Release:	%mkrel 1
Summary:	Computer monitoring and classroom management
Group:		Networking/Remote access
License:	GPLv2+
URL:		https://veyon.io/
Source0:	https://github.com/veyon/veyon/releases/download/v%{version}/veyon-%{version}-src.tar.bz2
Source1:	veyon.desktop
Source3:	ica-autostart.desktop
Source4:	ica-start
# Upstream 4.9 branch patches
#
BuildRequires:	cmake
BuildRequires:	cmake(Qt6LinguistTools)
BuildRequires:	cmake(Qt6Concurrent)
BuildRequires:	cmake(Qt6Core)
BuildRequires:	cmake(Qt6DBus)
BuildRequires:	cmake(Qt6Gui)
BuildRequires:	cmake(Qt6HttpServer)
BuildRequires:	cmake(Qt6Network)
BuildRequires:	cmake(Qt6QuickControls2)
BuildRequires:	cmake(Qt6Test)
BuildRequires:	cmake(Qt6Widgets)
BuildRequires:	cmake(Qt6Xml)
BuildRequires:	cmake(Qt6Core5Compat)
BuildRequires:	cmake(Qca-qt6)
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	pkgconfig(libfakekey)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libproc2)
BuildRequires:	pkgconfig(libsasl2)
BuildRequires:	pkgconfig(libvncclient)
BuildRequires:	pkgconfig(libvncserver)
BuildRequires:	pkgconfig(lzo2)
BuildRequires:	pkgconfig(polkit-agent-1)
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(xkbcommon)
BuildRequires:	pkgconfig(xkbcommon-x11)
BuildRequires:	pkgconfig(xtst)
BuildRequires:	pkgconfig(xrandr)
BuildRequires:	pkgconfig(xinerama)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pam-devel
BuildRequires:	desktop-file-utils
BuildRequires:	pkgconfig(xdamage)
BuildRequires:	openldap2-devel

Requires:	qca-qt6
Provides:	italc = %{version}-%{release}
Obsoletes:	italc < 4.7.4

%description
Veyon is a free and open source software for monitoring and controlling
computers across multiple platforms. Veyon supports you in teaching in digital
learning environments, performing virtual trainings or giving remote support.

The following features are available in Veyon:

    Overview: monitor all computers in one or multiple locations or classrooms
    Remote access: view or control computers to watch and support users
    Demo: broadcast the teacher's screen in realtime (fullscreen/window)
    Screen lock: draw attention to what matters right now
    Communication: send text messages to students
    Start and end lessons: log in and log out users all at once
    Screenshots: record learning progress and document infringements
    Programs & websites: launch programs and open website URLs remotely
    Teaching material: distribute and open documents, images and videos easily
    Administration: power on/off and reboot computers remotely


%package client
Summary:	Software for iTALC-clients
Group:		Networking/Remote access
Requires:	%{name} = %{version}
Obsoletes:	italc-client < 4.7.4
Provides:	italc-client = %{version}-%{release}

%description client
This package contains the software, needed by veyon-clients.

%package client-autostart
Summary:	Autostart for veyon-client
Group:		Networking/Remote access
Requires:	%{name} = %{version}
Requires:	veyon-client
Obsoletes:	italc-client-autostart < 4.7.4
Provides:	italc-client-autostart = %{version}-%{release}

%description client-autostart
This package contains autostart for veyon-client.

%package master
Summary:	veyon master software
Group:		Networking/Remote access
Requires:	%{name} = %{version}
Requires:	%{name}-client = %{version}
Obsoletes:	italc-master < 4.7.4
Provides:	italc-master = %{version}-%{release}

%description master
This package contains the actual master-software for accessing clients.

%prep
%autosetup -p1

%build
%cmake  -DCMAKE_INSTALL_LIBDIR:PATH=%{_lib} \
        -DSYSTEMD_SERVICE_INSTALL_DIR:PATH=%{_unitdir} \
        -DCMAKE_VEYON_X11VNC_EXTERNAL:BOOL=ON \
        -DCMAKE_POSITION_INDEPENDENT_CODE:BOOL=ON \
        -DCOTIRE_MINIMUM_NUMBER_OF_TARGET_SOURCES=9999 \
        -DWITH_PCH:BOOL=OFF \
        -DWITH_QT6:BOOL=ON
%cmake_build

%install
%cmake_install

# From Suse
# create the directories containing the auth-keys
mkdir -p %{buildroot}%{_sysconfdir}/%{name}/keys/{private,public}/{teacher,admin,supporter,other}
# create pseudo key files so RPM can own them (ghost files)
for role in admin supporter teacher; do
	touch %{buildroot}%{_sysconfdir}/%{name}/keys/{private,public}/$role/key
done

desktop-file-install --dir=%{buildroot}%{_datadir}/applications/ %{SOURCE1}

install -dm 755 %{buildroot}%{_sysconfdir}/xdg/autostart
install -m 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/xdg/autostart/
install -dm 755 %{buildroot}%{_bindir}
install -m 755 %{SOURCE4} %{buildroot}%{_bindir}/

%pre client
%{_sbindir}/groupadd -r -f %{italcgrp} 2>/dev/null ||:

%post client
if
    getent group %{italcgrp} >/dev/null
then
    : OK group %{italcgrp} already present
else
    groupadd -r %{italcgrp} 2>/dev/null || :
fi

%post master
if
    getent group %{italcgrp} >/dev/null
then
    : OK group %{italcgrp} already present
else
    groupadd -r %{italcgrp} 2>/dev/null || :
fi


%files
%doc README.md CONTRIBUTORS
%license COPYING
%dir %{_datadir}/veyon
%dir %{_datadir}/veyon/translations
%{_datadir}/veyon/translations/veyon*.qm

%files client
%{_bindir}/veyon-auth-helper
%{_bindir}/veyon-cli
%dir %{_sysconfdir}/%{name}
%dir %{_sysconfdir}/%{name}/keys
%dir %{_sysconfdir}/%{name}/keys/private
%defattr(0440,root,%{italcgrp},0750)
%dir %{_sysconfdir}/%{name}/keys/private/teacher
%dir %{_sysconfdir}/%{name}/keys/private/admin
%dir %{_sysconfdir}/%{name}/keys/private/supporter
%dir %{_sysconfdir}/%{name}/keys/private/other
%ghost %attr(0440,root,%{italcgrp}) %config(noreplace) %{_sysconfdir}/%{name}/keys/private/teacher/key
%ghost %attr(0440,root,%{italcgrp}) %config(noreplace) %{_sysconfdir}/%{name}/keys/private/admin/key
%ghost %attr(0440,root,%{italcgrp}) %config(noreplace) %{_sysconfdir}/%{name}/keys/private/supporter/key
%ghost %attr(0444,root,%{italcgrp}) %config(noreplace) %{_sysconfdir}/%{name}/keys/public/teacher/key
%ghost %attr(0444,root,%{italcgrp}) %config(noreplace) %{_sysconfdir}/%{name}/keys/public/admin/key
%ghost %attr(0444,root,%{italcgrp}) %config(noreplace) %{_sysconfdir}/%{name}/keys/public/supporter/key

%files master
%{_bindir}/veyon-master
%{_bindir}/veyon-configurator
%{_bindir}/veyon-server
%{_bindir}/veyon-service
%{_bindir}/veyon-worker
%{_datadir}/applications/%{name}.desktop
%{_datadir}/applications/%{name}-master.desktop
%{_datadir}/applications/%{name}-configurator.desktop
%{_iconsdir}/hicolor/48x48/apps/*.png
%{_iconsdir}/hicolor/scalable/apps/*.svg
%{_datadir}/pixmaps/%{name}-*.xpm
%{_datadir}/polkit-1/actions/io.veyon.veyon-configurator.policy
%{_unitdir}/%{name}.service
%dir %{_libdir}/veyon
%{_libdir}/veyon/authkeys.so
%{_libdir}/veyon/builtin-x11vnc-server.so
%{_libdir}/veyon/builtindirectory.so
%{_libdir}/veyon/demo.so
%{_libdir}/veyon/desktopservices.so
%{_libdir}/veyon/external-vnc-server.so
%{_libdir}/veyon/filetransfer.so
%{_libdir}/veyon/headless-vnc-server.so
%{_libdir}/veyon/ldap.so
%{_libdir}/veyon/libkldap-light.so
%{_libdir}/veyon/libldap-common.so
%{_libdir}/veyon/libveyon-core.so
%{_libdir}/veyon/linux-platform.so
%{_libdir}/veyon/powercontrol.so
%{_libdir}/veyon/remoteaccess.so
%{_libdir}/veyon/screenlock.so
%{_libdir}/veyon/screenshot.so
%{_libdir}/veyon/systemusergroups.so
%{_libdir}/veyon/textmessage.so
%{_libdir}/veyon/usersessioncontrol.so
%{_libdir}/veyon/webapi.so


%files client-autostart
%{_sysconfdir}/xdg/autostart/ica-autostart.desktop
%{_bindir}/ica-start


%changelog
* Sun Apr 06 2025 daviddavid <daviddavid> 4.9.4-1.mga10
+ Revision: 2173929
- new version: 4.9.4
- backport upstream patch to adopt libproc2 4.0.5 API change
- rebuild for new procps-ng 4.0.5

* Tue Jan 07 2025 daviddavid <daviddavid> 4.9.1-1.mga10
+ Revision: 2135853
- new version: 4.9.1

* Tue Jul 16 2024 papoteur <papoteur> 4.8.3-1.mga10
+ Revision: 2081772
- new version 4.8.3

* Sun Nov 05 2023 daviddavid <daviddavid> 4.8.2-1.mga10
+ Revision: 2004668
- new version: 4.8.2
- remove merged upstream patch
- re-enable webapi plugin

* Sun Nov 05 2023 daviddavid <daviddavid> 4.7.4-6.mga10
+ Revision: 2004657
- rebuild for new procps 4.x
- backport upstream patch to add support for libproc2
- fix some owner dir

* Sun Jun 11 2023 daviddavid <daviddavid> 4.7.4-5.mga9
+ Revision: 1961786
- remove unmaintained libXp support (fix mga#31867)

* Thu Nov 10 2022 papoteur <papoteur> 4.7.4-4.mga9
+ Revision: 1905143
- Obsolete italc and italc-client-autostart

* Thu Sep 15 2022 papoteur <papoteur> 4.7.4-3.mga9
+ Revision: 1888977
- Build with Qt6
  thus disabling webapi

* Sun Sep 11 2022 wally <wally> 4.7.4-2.mga9
+ Revision: 1887194
- obsolete old italc pkgs
- properly fix RPATH 'issue'

* Sat Sep 10 2022 papoteur <papoteur> 4.7.4-1.mga9
+ Revision: 1886476
- new 4.7.4
- veyon is replacing italc
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild
+ wally <wally>
- rebuild for openssl 3.0.0

* Thu Dec 17 2020 umeabot <umeabot> 3.0.3-6.mga8
+ Revision: 1658593
- Rebuild for new Qt5

* Wed Oct 21 2020 ns80 <ns80> 3.0.3-5.mga8
+ Revision: 1637577
- add Ubuntu patches for many CVEs in bundled libvnc (mga#27404)

* Sat Feb 15 2020 daviddavid <daviddavid> 3.0.3-4.mga8
+ Revision: 1525793
- use new cmake macros
- split out all Qt5 BRs
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Sat Mar 30 2019 umeabot <umeabot> 3.0.3-3.mga7
+ Revision: 1381938
- Qt5 Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 3.0.3-2.mga7
+ Revision: 1298335
- Mageia 7 Mass Rebuild

* Sat Sep 16 2017 guillomovitch <guillomovitch> 3.0.3-1.mga7
+ Revision: 1154648
- new version 3.0.3

* Sat Oct 29 2016 alexl <alexl> 2.0.2-5.mga6
+ Revision: 1063884
- calculate minimum width based on width of rendered text

* Tue Feb 09 2016 umeabot <umeabot> 2.0.2-4.mga6
+ Revision: 951474
- Mageia 6 Mass Rebuild

* Sun Dec 28 2014 alexl <alexl> 2.0.2-3.mga5
+ Revision: 807016
- added GlobalConfig.xml

* Fri Dec 26 2014 alexl <alexl> 2.0.2-2.mga5
+ Revision: 806332
- ensure that $DISPLAY is unset before evoking the imc -createkeypair command (from Debian)

* Fri Dec 19 2014 alexl <alexl> 2.0.2-1.mga5
+ Revision: 804237
- version 2.0.2, which fix mga#12870

* Sat Nov 29 2014 alexl <alexl> 2.0.1-7.mga5
+ Revision: 799923
- added italc-client-autostart pkg

* Wed Oct 15 2014 umeabot <umeabot> 2.0.1-6.mga5
+ Revision: 746752
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.0.1-5.mga5
+ Revision: 680579
- Mageia 5 Mass Rebuild

* Wed Aug 20 2014 luigiwalser <luigiwalser> 2.0.1-4.mga5
+ Revision: 666009
- add patch from harbour to fix CVE-2014-4607 in bundled minilzo

* Wed Apr 02 2014 dams <dams> 2.0.1-3.mga5
+ Revision: 611417
- add initial configuration (mga#13035)

* Wed Apr 02 2014 dams <dams> 2.0.1-2.mga5
+ Revision: 611392
- update .desktop file (i18n) mga#13035

* Thu Feb 27 2014 dams <dams> 2.0.1-1.mga5
+ Revision: 597650
- new version 2.0.1

* Fri Oct 18 2013 umeabot <umeabot> 2.0.0-3.mga4
+ Revision: 506154
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 2.0.0-2.mga3
+ Revision: 354590
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 08 2013 bersuit <bersuit> 2.0.0-1.mga3
+ Revision: 343004
- Fixed BuildRequires: java-devel
- Update to New Version 2.0.0

* Sat May 14 2011 dmorgan <dmorgan> 1.0.13-1.mga1
+ Revision: 98418
- imported package italc

